Module generic

Module generic 

Generic TMCM implementation - uses TMCL instructions without making assumptions about parameters.

The types in module only provides a minimum of compile time guarantees. It is therefore preferable to use a less generic module that will fail to compile if it is attempted to write to a read only register and such. This module is only recommended to use if no such module exists.

Modules

instructions
Instructions available for the generic TMCM module.

Structs

GenericModule
This type represents a generic TMCM module.