MVP

Struct MVP 

pub struct MVP { /* private fields */ }
MVP - Move to Position

A movement towards the specified position is started, with automatic generation of acceleration and deceleration ramps. The maximum velocity and acceleration are defined by axis parameters #4 and #5.

Implementations

Source

impl MVP

pub fn new(motor_number: u8, value: MoveOperation) -> MVP