pub struct MVP { /* private fields */ }Expand description
MVP - Move to Position
A movement towards the specified position is started, with automatic generation of acceleration and deceleration ramps. The maximum velocity and acceleration are defined by axis parameters #4 and #5.
Implementations